@@ -1,14 +1,14 @@
 /*
  * This file is part of hildon-libs
  *
- * Copyright (C) 2005 Nokia Corporation.
+ * Copyright (C) 2005, 2006 Nokia Corporation, all rights reserved.
  *
- * Contact: Luc Pionchon <luc.pionchon@nokia.com>
+ * Contact: Michael Dominic Kostrzewa <michael.kostrzewa@nokia.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
- * as published by the Free Software Foundation; either version 2.1 of
- * the License, or (at your option) any later version.
+ * as published by the Free Software Foundation; version 2.1 of
+ * the License.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -410,6 +410,7 @@ static void force_to_wrap_truncated(HildonBanner *banner){
   GtkLabel *label;
   PangoLayout *layout;
   int width_text, width_max;
+  int width = -1;
 
   label = GTK_LABEL(banner->priv->label);
 
@@ -427,9 +428,12 @@ static void force_to_wrap_truncated(HildonBanner *banner){
     pango_layout_set_width (layout, width_max * PANGO_SCALE);
     pango_layout_get_extents (layout, NULL, &logical);
 
-    gtk_widget_set_size_request (GTK_WIDGET (label),
-                                 PANGO_PIXELS (logical.width), -1);
+    width = PANGO_PIXELS (logical.width);
   }
+
+  /* use fixed width when wrapping or natural one otherwise */
+  gtk_widget_set_size_request (GTK_WIDGET (label),
+			       width, -1);
 }
 
 
@@ -556,7 +560,7 @@ static void hildon_banner_ensure_child(HildonBanner *self,
       /* Use user provided widget or create a new one */
       self->priv->main_item = widget = user_widget ? 
          user_widget : GTK_WIDGET(g_object_new_valist(type, first_property, args));
-      gtk_box_pack_start(GTK_BOX(self->priv->layout), widget, FALSE, TRUE, 0);
+      gtk_box_pack_start(GTK_BOX(self->priv->layout), widget, TRUE, TRUE, 0);
    }
 
    /* We make sure that the widget exists in desired position. Different
@@ -610,6 +614,7 @@ void hildon_banner_show_information(GtkWidget *widget,
    hildon_banner_ensure_child(banner, NULL, 0, GTK_TYPE_IMAGE, 
       "pixel-size", HILDON_ICON_PIXEL_SIZE_NOTE, 
       "icon-name", icon_name ? icon_name : HILDON_BANNER_DEFAULT_ICON,
+      "yalign", 0.0, 
       NULL);
    hildon_banner_set_text(banner, text);
    hildon_banner_bind_label_style(banner, NULL);
@@ -647,6 +652,7 @@ void hildon_banner_show_information_with_markup(GtkWidget *widget,
    hildon_banner_ensure_child(banner, NULL, 0, GTK_TYPE_IMAGE, 
       "pixel-size", HILDON_ICON_PIXEL_SIZE_NOTE, 
       "icon-name", icon_name ? icon_name : HILDON_BANNER_DEFAULT_ICON,
+      "yalign", 0.0, 
       NULL);
    hildon_banner_set_markup(banner, markup);
    hildon_banner_bind_label_style(banner, NULL);
@@ -716,7 +722,7 @@ GtkWidget *hildon_banner_show_animation(GtkWidget *widget,
    /* Prepare banner */
    banner = hildon_banner_get_instance_for_widget(widget, FALSE);
    hildon_banner_ensure_child(banner, image_widget, 0,
-      GTK_TYPE_IMAGE, NULL);
+      GTK_TYPE_IMAGE, "yalign", 0.0, NULL);
    hildon_banner_set_text(banner, text);
    hildon_banner_bind_label_style(banner, NULL);
 
