@@ -1,14 +1,14 @@
 /*
  * This file is part of hildon-libs
  *
- * Copyright (C) 2005 Nokia Corporation.
+ * Copyright (C) 2005, 2006 Nokia Corporation, all rights reserved.
  *
- * Contact: Luc Pionchon <luc.pionchon@nokia.com>
+ * Contact: Michael Dominic Kostrzewa <michael.kostrzewa@nokia.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
- * as published by the Free Software Foundation; either version 2.1 of
- * the License, or (at your option) any later version.
+ * as published by the Free Software Foundation; version 2.1 of
+ * the License.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -24,10 +24,10 @@
 
 /**
  * SECTION:hildon-color-button
- * @short_description: A widget to open HildonColorSelector
- * @see_also: #HildonColorSelector, #HildonColorPopup
+ * @short_description: A widget to open HildonColorChooserDialog
+ * @see_also: #HildonColorChooserDialog, #HildonColorPopup
  *
- * HildonColorButton is a widget to open a HildonColorSelector.
+ * HildonColorButton is a widget to open a HildonColorChooserDialog.
  * The selected color is shown in the button.
  * The selected color is a property of the button.
  * The property name is "color" and its type is GtkColor.
@@ -42,7 +42,7 @@
 #include <hildon-widgets/hildon-defines.h>
 
 #include "hildon-color-button.h"
-#include "hildon-color-selector.h"
+#include "hildon-color-chooser-dialog.h"
 
 #define HILDON_COLOR_BUTTON_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE\
               ((obj), HILDON_TYPE_COLOR_BUTTON, HildonColorButtonPrivate))
@@ -110,6 +110,10 @@ static gboolean
 hildon_color_button_mnemonic_activate( GtkWidget *widget,
                                        gboolean group_cycling );
 
+static void
+draw_grid (GdkDrawable *drawable, GdkGC *gc, 
+           int x, int y, 
+           gint w, gint h);
 
 static gpointer parent_class = NULL;
 
@@ -177,6 +181,21 @@ hildon_color_button_class_init(HildonColorButtonClass *klass)
   g_type_class_add_private (gobject_class, sizeof (HildonColorButtonPrivate));
 }
 
+/* Draw a dotted grid over the specified area to make it look 
+ * insensitive. Actually, we should generate that pixbuf once and 
+ * just render it over later... */
+static void
+draw_grid (GdkDrawable *drawable, GdkGC *gc, 
+           int x, int y,
+           gint w, gint h)
+{
+  int currentx;
+  int currenty;
+  for (currenty = y; currenty <= h; currenty++)
+      for (currentx = ((currenty % 2 == 0) ? x : x + 1); currentx <= w; currentx += 2)
+        gdk_draw_point (drawable, gc, currentx, currenty);
+}
+
 /* Handle exposure events for the color picker's drawing area */
 static gint
 hildon_color_field_expose_event(GtkWidget *widget, GdkEventExpose *event,
@@ -200,34 +219,42 @@ hildon_color_field_expose_event(GtkWidget *widget, GdkEventExpose *event,
     gdk_gc_set_rgb_fg_color(cb->priv->gc, &outer_border);
     /* draw the outer border as a filled rectangle */
     gdk_draw_rectangle(widget->window,
-            cb->priv->gc,
-            TRUE,
-            event->area.x,
-            event->area.y,
-            event->area.width,
-            event->area.height);
+                       (GTK_WIDGET_IS_SENSITIVE (widget)) ?  cb->priv->gc : widget->style->bg_gc [GTK_STATE_INSENSITIVE],
+                       TRUE,
+                       0, 
+                       0,
+                       widget->allocation.width,
+                       widget->allocation.height);
 
     /* serve the inner border color to the Graphic Context */
     gdk_gc_set_rgb_fg_color(cb->priv->gc, &inner_border);
     /* draw the inner border as a filled rectangle */
     gdk_draw_rectangle(widget->window,
-            cb->priv->gc,
-            TRUE,
-            event->area.x + OUTER_BORDER_THICKNESS,
-            event->area.y + OUTER_BORDER_THICKNESS,
-            event->area.width  - (OUTER_BORDER_THICKNESS*2),
-            event->area.height - (OUTER_BORDER_THICKNESS*2));
+                       cb->priv->gc,
+                       TRUE,
+                       OUTER_BORDER_THICKNESS, 
+                       OUTER_BORDER_THICKNESS,
+                       widget->allocation.width - (OUTER_BORDER_THICKNESS * 2),
+                       widget->allocation.height - (OUTER_BORDER_THICKNESS * 2));
 
     /* serve the actual color to the Graphic Context */
     gdk_gc_set_rgb_fg_color(cb->priv->gc, &cb->priv->color);
     /* draw the actual rectangle */
     gdk_draw_rectangle(widget->window,
-            cb->priv->gc,
-            TRUE,
-            event->area.x + (INNER_BORDER_THICKNESS + OUTER_BORDER_THICKNESS),
-            event->area.y + (INNER_BORDER_THICKNESS + OUTER_BORDER_THICKNESS),
-            event->area.width  - ((INNER_BORDER_THICKNESS + OUTER_BORDER_THICKNESS)*2),
-            event->area.height - ((INNER_BORDER_THICKNESS + OUTER_BORDER_THICKNESS)*2));
+                       cb->priv->gc,
+                       TRUE,
+                       INNER_BORDER_THICKNESS + OUTER_BORDER_THICKNESS,
+                       INNER_BORDER_THICKNESS + OUTER_BORDER_THICKNESS,
+                       widget->allocation.width - ((INNER_BORDER_THICKNESS + OUTER_BORDER_THICKNESS)*2),
+                       widget->allocation.height - ((INNER_BORDER_THICKNESS + OUTER_BORDER_THICKNESS)*2));
+
+    if (! GTK_WIDGET_IS_SENSITIVE (widget)) {
+            draw_grid (GDK_DRAWABLE (widget->window), widget->style->bg_gc [GTK_STATE_INSENSITIVE], 
+                       INNER_BORDER_THICKNESS + OUTER_BORDER_THICKNESS,
+                       INNER_BORDER_THICKNESS + OUTER_BORDER_THICKNESS,
+                       widget->allocation.width  - ((INNER_BORDER_THICKNESS + OUTER_BORDER_THICKNESS)*2) + 2,
+                       widget->allocation.height - ((INNER_BORDER_THICKNESS + OUTER_BORDER_THICKNESS)*2) + 2);
+    }
 
     return FALSE;
 }
@@ -324,30 +351,30 @@ static void
 hildon_color_button_clicked(GtkButton *button)
 {
   HildonColorButton *cb = HILDON_COLOR_BUTTON(button);
-  HildonColorSelector *cs_dialog = HILDON_COLOR_SELECTOR(cb->priv->dialog);
-
+  HildonColorChooserDialog *cs_dialog = HILDON_COLOR_CHOOSER_DIALOG(cb->priv->dialog);
+  
   /* Popup the color selector dialog */
   if (!cs_dialog)
   {
     /* The dialog hasn't been created yet, do it. */
     GtkWidget *parent = gtk_widget_get_toplevel(GTK_WIDGET(cb));
-    cb->priv->dialog = hildon_color_selector_new(GTK_WINDOW(parent));
-    cs_dialog = HILDON_COLOR_SELECTOR(cb->priv->dialog);
-    
+    cb->priv->dialog = hildon_color_chooser_dialog_new(GTK_WINDOW(parent));
+    cs_dialog = HILDON_COLOR_CHOOSER_DIALOG(cb->priv->dialog);
     if (parent)
       gtk_window_set_transient_for(GTK_WINDOW(cs_dialog), GTK_WINDOW(parent));
   }
-  
+
   /* Set the initial color for the color selector dialog */
-  hildon_color_selector_set_color(cs_dialog, &cb->priv->color);
-  
+  hildon_color_chooser_dialog_set_color(cs_dialog, &cb->priv->color);
+ 
   /* Update the color for color button if selection was made */
   if (gtk_dialog_run(GTK_DIALOG(cs_dialog)) == GTK_RESPONSE_OK)
   {
-    cb->priv->color = *hildon_color_selector_get_color(cs_dialog);
+    hildon_color_chooser_dialog_get_color(cs_dialog, &cb->priv->color);
     hildon_color_button_set_color( HILDON_COLOR_BUTTON( button ), 
             &(cb->priv->color) );
-  }
+  } 
+
   gtk_widget_hide(GTK_WIDGET(cs_dialog));
 }
 
