@@ -1,14 +1,14 @@
 /*
  * This file is part of hildon-libs
  *
- * Copyright (C) 2005 Nokia Corporation.
+ * Copyright (C) 2005, 2006 Nokia Corporation, all rights reserved.
  *
- * Contact: Luc Pionchon <luc.pionchon@nokia.com>
+ * Contact: Michael Dominic Kostrzewa <michael.kostrzewa@nokia.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
- * as published by the Free Software Foundation; either version 2.1 of
- * the License, or (at your option) any later version.
+ * as published by the Free Software Foundation; version 2.1 of
+ * the License.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -29,12 +29,24 @@
 #include <gtk/gtkwindow.h>
 #include <gtk/gtkdialog.h>
 
+G_BEGIN_DECLS
+
 typedef struct
 {
-	  GtkWidget *ctrlbar_red, *ctrlbar_green, *ctrlbar_blue;
+  GtkWidget *ctrlbar_red;
+  GtkWidget *ctrlbar_green;
+  GtkWidget *ctrlbar_blue;
+
 } HildonColorPopup;
 
-GtkWidget *hildon_color_popup_new(GtkWindow * parent, GdkColor *initial_color, HildonColorPopup *popupdata);
+GtkWidget *hildon_color_popup_new(GtkWindow        *parent,
+                                  const GdkColor   *initial_color,
+                                  HildonColorPopup *popupdata);
 
-void hildon_color_popup_set_color_from_sliders(GdkColor *color, HildonColorPopup *popupdata);
-#endif
+void       hildon_color_popup_set_color_from_sliders(GdkColor *color,
+                                                     HildonColorPopup *popupdata);
+
+
+G_END_DECLS
+
+#endif /* __HILDON_COLOR_POPUP_H__ */
