@@ -1,14 +1,14 @@
 /*
  * This file is part of hildon-libs
  *
- * Copyright (C) 2005 Nokia Corporation.
+ * Copyright (C) 2005, 2006 Nokia Corporation, all rights reserved.
  *
- * Contact: Luc Pionchon <luc.pionchon@nokia.com>
+ * Contact: Michael Dominic Kostrzewa <michael.kostrzewa@nokia.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
- * as published by the Free Software Foundation; either version 2.1 of
- * the License, or (at your option) any later version.
+ * as published by the Free Software Foundation; version 2.1 of
+ * the License.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -29,7 +29,7 @@
  * @see_also: #HildonCalendarPopup, #HildonTimeEditor
  * 
  * HildonDateEditor is a widget with three entry fields (day, month,
- * year) and an icon (eventbox): clicking on the icon opens up a
+ * year) and an icon (button): clicking on the icon opens up a
  * HildonCalendarPopup.
  */
 
@@ -56,6 +56,7 @@
 
 #include<libintl.h>
 #define _(string) dgettext(PACKAGE, string)
+#define c_(String) dgettext("hildon-common-strings", String)
 
 #define ENTRY_BORDERS 11
 #define DATE_EDITOR_HEIGHT 30
@@ -81,14 +82,11 @@ hildon_date_editor_class_init(HildonDateEditorClass * editor_class);
 static void hildon_date_editor_init(HildonDateEditor * editor);
 
 static gboolean
-hildon_date_editor_icon_press(GtkWidget * widget, GdkEventButton * event,
+hildon_date_editor_icon_press(GtkWidget * widget, 
                               gpointer data);
 
 static gboolean
-hildon_date_editor_entry_released(GtkWidget * widget,
-                                  GdkEventButton * event, gpointer data);
-static gboolean
-hildon_date_editor_released(GtkWidget * widget, GdkEventButton * event,
+hildon_date_editor_released(GtkWidget * widget, 
                             gpointer data);
 
 static gboolean
@@ -98,7 +96,9 @@ hildon_date_editor_keypress(GtkWidget * widget, GdkEventKey * event,
 static gboolean
 hildon_date_editor_keyrelease(GtkWidget * widget, GdkEventKey * event,
                               gpointer data);
-static void
+static gboolean
+hildon_date_editor_clicked(GtkWidget * widget, gpointer data);
+static gint
 hildon_date_editor_entry_validate(GtkWidget *widget, gpointer data);
 
 static void
@@ -155,7 +155,7 @@ struct _HildonDateEditorPrivate {
     gboolean calendar_icon_pressed;
 
     GtkWidget *frame;             /* borders around the date */
-    GtkWidget *d_event_box_image; /* icon */
+    GtkWidget *d_button_image; /* icon */
     GtkWidget *d_box_date;        /* hbox for date */
 
     GtkWidget *d_entry; /* GtkEntry for day */
@@ -448,48 +448,40 @@ static void hildon_date_editor_init(HildonDateEditor * editor)
 
     priv->d_box_date = gtk_hbox_new(FALSE, 0);
 
-    priv->d_event_box_image = gtk_event_box_new();
+    priv->d_button_image = gtk_button_new();
     priv->calendar_icon = gtk_image_new();
     real_set_calendar_icon_state(priv, FALSE);
+    GTK_WIDGET_UNSET_FLAGS(priv->d_button_image, GTK_CAN_FOCUS | GTK_CAN_DEFAULT);
 
     apply_locale_field_order(priv);
 
     gtk_container_add(GTK_CONTAINER(priv->frame), priv->d_box_date);
-    gtk_container_add(GTK_CONTAINER(priv->d_event_box_image), priv->calendar_icon);
+    gtk_container_add(GTK_CONTAINER(priv->d_button_image), priv->calendar_icon);
+    gtk_button_set_relief(GTK_BUTTON(priv->d_button_image), GTK_RELIEF_NONE);
+    gtk_button_set_focus_on_click(GTK_BUTTON(priv->d_button_image), FALSE);
 
     gtk_widget_set_parent(priv->frame, GTK_WIDGET(editor));
-    gtk_widget_set_parent(priv->d_event_box_image, GTK_WIDGET(editor));
+    gtk_widget_set_parent(priv->d_button_image, GTK_WIDGET(editor));
     gtk_widget_show_all(priv->frame);
-    gtk_widget_show_all(priv->d_event_box_image);
+    gtk_widget_show_all(priv->d_button_image);
     
-    /* image signal connects */
-    g_signal_connect(GTK_OBJECT(priv->d_event_box_image), "button_press_event",
+    /* image button signal connects */
+    g_signal_connect(GTK_OBJECT(priv->d_button_image), "pressed",
                      G_CALLBACK(hildon_date_editor_icon_press), editor);
-    g_signal_connect(GTK_OBJECT(priv->d_event_box_image),
-                     "button_release_event",
+    g_signal_connect(GTK_OBJECT(priv->d_button_image), "released",
                      G_CALLBACK(hildon_date_editor_released), editor);
-    g_signal_connect(GTK_OBJECT(priv->d_event_box_image), "key-press-event",
-                     G_CALLBACK(hildon_date_editor_keypress), editor);
-    g_signal_connect(GTK_OBJECT(priv->calendar_icon), "key-press-event",
+    g_signal_connect(GTK_OBJECT(priv->d_button_image), "clicked",
+                     G_CALLBACK(hildon_date_editor_clicked), editor);
+    g_signal_connect(GTK_OBJECT(priv->d_button_image), "key_press_event",
                      G_CALLBACK(hildon_date_editor_keypress), editor);
 
-
-    /* entry signal connects */
-    g_signal_connect(GTK_OBJECT(priv->d_entry), "button_release_event",
-                     G_CALLBACK(hildon_date_editor_entry_released), editor);
-    
+    /* entry signal connects */    
     g_signal_connect(GTK_OBJECT(priv->d_entry), "focus-in-event",
                      G_CALLBACK(hildon_date_editor_entry_focusin), editor);
 
-    g_signal_connect(GTK_OBJECT(priv->m_entry), "button_release_event",
-                     G_CALLBACK(hildon_date_editor_entry_released), editor);
-
     g_signal_connect(GTK_OBJECT(priv->m_entry), "focus-in-event",
                      G_CALLBACK(hildon_date_editor_entry_focusin), editor);
 
-    g_signal_connect(GTK_OBJECT(priv->y_entry), "button_release_event",
-                     G_CALLBACK(hildon_date_editor_entry_released), editor);
-
     g_signal_connect(GTK_OBJECT(priv->y_entry), "focus-in-event",
                      G_CALLBACK(hildon_date_editor_entry_focusin), editor);
 
@@ -637,7 +629,7 @@ static void hildon_child_forall(GtkContainer * container,
 
     if (include_internals) {
         (*callback) (priv->frame, callback_data);
-        (*callback) (priv->d_event_box_image, callback_data);
+        (*callback) (priv->d_button_image, callback_data);
     }
 }
 
@@ -651,9 +643,9 @@ static void hildon_date_editor_destroy(GtkObject * self)
         gtk_widget_unparent(priv->frame);
         priv->frame = NULL;
     }
-    if (priv->d_event_box_image) {
-        gtk_widget_unparent(priv->d_event_box_image);
-        priv->d_event_box_image = NULL;
+    if (priv->d_button_image) {
+        gtk_widget_unparent(priv->d_button_image);
+        priv->d_button_image = NULL;
     }
     if (priv->delims) {
         g_list_free(priv->delims);
@@ -801,36 +793,14 @@ void hildon_date_editor_get_date(HildonDateEditor * date,
       (guint) atoi(gtk_entry_get_text(GTK_ENTRY(priv->d_entry)));
 }
 
+/* icon button press event */
 static gboolean hildon_date_editor_icon_press(GtkWidget * widget,
-                                              GdkEventButton * event,
                                               gpointer data)
 {
     g_assert(GTK_IS_WIDGET(widget));
-    g_assert(event != NULL);
     g_assert(HILDON_IS_DATE_EDITOR(data));
 
-    if (event->button == 1)
-       hildon_date_editor_set_calendar_icon_state(HILDON_DATE_EDITOR(data), TRUE);
-
-    return FALSE;
-}
-
-static gboolean hildon_date_editor_entry_released(GtkWidget * widget,
-                                                  GdkEventButton * event,
-                                                  gpointer data)
-{
-    HildonDateEditor *ed;
-    HildonDateEditorPrivate *priv;
-
-    ed = HILDON_DATE_EDITOR(data);
-    priv = HILDON_DATE_EDITOR_GET_PRIVATE(ed);
-
-    if (event->button == 1) {
-        /* We might not get focus because of invalid values in entries */
-        if (GTK_WIDGET_HAS_FOCUS(widget))
-			g_idle_add((GSourceFunc)
-					_hildon_date_editor_entry_select_all, GTK_ENTRY(widget));
-    }
+    hildon_date_editor_set_calendar_icon_state(HILDON_DATE_EDITOR(data), TRUE);
 
     return FALSE;
 }
@@ -839,11 +809,8 @@ static gboolean hildon_date_editor_entry_focusin(GtkWidget * widget,
                                                  GdkEventFocus * event,
                                                  gpointer data)
 {
-    if (!GTK_ENTRY(widget)->button)
-    {
-		g_idle_add((GSourceFunc)
-				_hildon_date_editor_entry_select_all, GTK_ENTRY(widget));
-    }
+    g_idle_add((GSourceFunc)
+               _hildon_date_editor_entry_select_all, GTK_ENTRY(widget));
 
     return FALSE;
 }
@@ -884,19 +851,35 @@ static void popup_calendar_dialog(HildonDateEditor *ed)
 
 /* button released */
 static gboolean hildon_date_editor_released(GtkWidget * widget,
-                                            GdkEventButton * event,
                                             gpointer data)
 {
     HildonDateEditor *ed;
 
     g_assert(GTK_IS_WIDGET(widget));
-    g_assert(event != NULL);
     g_assert(HILDON_IS_DATE_EDITOR(data));
 
     ed = HILDON_DATE_EDITOR(data);
 
-    if (hildon_date_editor_set_calendar_icon_state(ed, FALSE))
-        popup_calendar_dialog(ed);
+    /* restores the icon state. The clicked cycle raises the dialog */
+    hildon_date_editor_set_calendar_icon_state(ed, FALSE);
+
+    return FALSE;
+}
+
+/* button released */
+static gboolean hildon_date_editor_clicked(GtkWidget * widget,
+					   gpointer data)
+{
+    HildonDateEditor *ed;
+
+    g_assert(GTK_IS_WIDGET(widget));
+    g_assert(HILDON_IS_DATE_EDITOR(data));
+
+    ed = HILDON_DATE_EDITOR(data);
+
+    /* restores the non-clicked button state and raises the dialog */
+    hildon_date_editor_set_calendar_icon_state(ed, FALSE);
+    popup_calendar_dialog(ed);
 
     return FALSE;
 }
@@ -905,7 +888,7 @@ static gboolean hildon_date_editor_released(GtkWidget * widget,
    when the all of the fields are filled. 
    Earlier this was called whenever an entry changed */
 /* FIXME: Validation on focus_out is broken by concept */
-static void
+static gint
 hildon_date_editor_entry_validate(GtkWidget *widget, gpointer data)
 {
     HildonDateEditor *ed;
@@ -922,7 +905,7 @@ hildon_date_editor_entry_validate(GtkWidget *widget, gpointer data)
     priv = HILDON_DATE_EDITOR_GET_PRIVATE(ed);
 
     if (priv->skip_validation)
-       return;
+       return error_code;
 
     /*check if the calling entry is empty*/
     text = gtk_entry_get_text(GTK_ENTRY(widget));
@@ -935,18 +918,20 @@ hildon_date_editor_entry_validate(GtkWidget *widget, gpointer data)
       else
          g_signal_emit(ed, date_editor_signals[DATE_ERROR], 0, EMPTY_YEAR, &r);
 
-      return;
+      /* restore empty entry to safe value */
+      hildon_date_editor_set_date (ed, priv->year, priv->month, priv->day);
+      return error_code;
     }
 
     /* Ok, we now check validity. Some fields can be empty */
     text = gtk_entry_get_text(GTK_ENTRY(priv->d_entry));
-    if (text == NULL || text[0] == 0) return;
+    if (text == NULL || text[0] == 0) return error_code;
     d = atoi(text);
     text = gtk_entry_get_text(GTK_ENTRY(priv->m_entry));
-    if (text == NULL || text[0] == 0) return;
+    if (text == NULL || text[0] == 0) return error_code;
     m = atoi(text);
     text = gtk_entry_get_text(GTK_ENTRY(priv->y_entry));
-    if (text == NULL || text[0] == 0) return;
+    if (text == NULL || text[0] == 0) return error_code;
     y = atoi(text);
 
     /* Did it actually change? */
@@ -1013,9 +998,6 @@ hildon_date_editor_entry_validate(GtkWidget *widget, gpointer data)
             g_idle_add ((GSourceFunc) 
                     _hildon_date_editor_entry_select_all, 
                     widget);
-
-    	    /* Set focus back to invalid entry */
-            gtk_widget_grab_focus(widget);
         }
     }
 
@@ -1023,6 +1005,7 @@ hildon_date_editor_entry_validate(GtkWidget *widget, gpointer data)
        reformatting can be needed even in a such case that numerical
        values of the date components are the same as earlier. */
     hildon_date_editor_set_date(ed, y, m, d);
+    return error_code;
 }
 
 /* When entry becomes full, we move the focus to the next field.
@@ -1031,6 +1014,8 @@ static void
 hildon_date_editor_entry_changed(GtkEditable *ed, gpointer data)
 {
   GtkEntry *entry;
+  gint error_code;
+  HildonDateEditorPrivate *priv;
 
   g_assert(GTK_IS_ENTRY(ed));
   g_assert(HILDON_IS_DATE_EDITOR(data));
@@ -1040,8 +1025,13 @@ hildon_date_editor_entry_changed(GtkEditable *ed, gpointer data)
   /* If day entry is full, move to next entry or validate */
   if (g_utf8_strlen(gtk_entry_get_text(entry), -1) == gtk_entry_get_max_length(entry))
     {
-      if (!gtk_widget_child_focus(GTK_WIDGET(data), GTK_DIR_RIGHT))
-        hildon_date_editor_entry_validate(GTK_WIDGET(entry), data);
+      error_code = hildon_date_editor_entry_validate(GTK_WIDGET(entry), data);
+      if (error_code == NO_ERROR)
+	{
+	  priv = HILDON_DATE_EDITOR_GET_PRIVATE(HILDON_DATE_EDITOR(data));
+	  priv->skip_validation = TRUE;
+	  gtk_widget_child_focus(GTK_WIDGET(data), GTK_DIR_RIGHT);
+	}
     }
 }
 
@@ -1079,6 +1069,7 @@ static gboolean hildon_date_editor_keypress(GtkWidget * widget,
     HildonDateEditor *ed;
     HildonDateEditorPrivate *priv;
     gint pos;
+    gboolean r;
 
     g_assert(HILDON_IS_DATE_EDITOR(data));
     g_assert(GTK_IS_ENTRY(widget));
@@ -1086,15 +1077,26 @@ static gboolean hildon_date_editor_keypress(GtkWidget * widget,
     ed = HILDON_DATE_EDITOR(data);
     priv = HILDON_DATE_EDITOR_GET_PRIVATE(ed);
     pos = gtk_editable_get_position(GTK_EDITABLE(widget));
-	
+
+    /* Show error message in case the key pressed is not allowed 
+       (only digits and control characters are allowed )*/
+    if (!g_unichar_isdigit(event->keyval) && !(event->keyval & 0xF000)) {
+        g_signal_emit(ed, date_editor_signals[DATE_ERROR], 0, INVALID_CHAR, &r);        
+        return TRUE;
+    }
+
     switch (event->keyval) {
     case GDK_Left:
-        (void) gtk_widget_child_focus(GTK_WIDGET(data), GTK_DIR_LEFT);
-        return TRUE;
+        if (pos == 0) {
+          (void) gtk_widget_child_focus(GTK_WIDGET(data), GTK_DIR_LEFT);
+          return TRUE;
+        }
         break;
     case GDK_Right:
-        (void) gtk_widget_child_focus(GTK_WIDGET(data), GTK_DIR_RIGHT);
-        return TRUE;
+        if (pos >= g_utf8_strlen(gtk_entry_get_text(GTK_ENTRY(widget)), -1)) {
+          (void) gtk_widget_child_focus(GTK_WIDGET(data), GTK_DIR_RIGHT);
+          return TRUE;
+        }
         break;
     case GDK_Return:
     case GDK_ISO_Enter:
@@ -1117,7 +1119,17 @@ static gboolean hildon_date_editor_entry_focus_out(GtkWidget * widget,
                                              GdkEventFocus * event,
                                              gpointer data)
 {
+  HildonDateEditor *ed;
+  HildonDateEditorPrivate *priv;
+
+  g_assert(HILDON_IS_DATE_EDITOR(data));
+
+  ed = HILDON_DATE_EDITOR(data);
+  priv = HILDON_DATE_EDITOR_GET_PRIVATE(ed);
+
   hildon_date_editor_entry_validate(widget, data);
+  priv->skip_validation = FALSE;
+
   return FALSE;
 }
 
@@ -1155,10 +1167,13 @@ hildon_date_editor_date_error(HildonDateEditor *editor,
       gtk_infoprintf(NULL, _("ckct_ib_set_a_value_within_range"),
                      priv->min_year, priv->max_year);
       break;
+    case INVALID_CHAR:
+      gtk_infoprint(NULL, c_("ckct_ib_illegal_character"));
+      break;
     case INVALID_DATE:
       gtk_infoprint(NULL, _("ckct_ib_date_does_not_exist"));
       break;
-   default:
+    default:
       /*default error message ?*/
       break;
     }
@@ -1180,7 +1195,7 @@ static void hildon_date_editor_size_request(GtkWidget * widget,
 
     /* Our own children affect our size */
     gtk_widget_size_request(priv->frame, &f_req);
-    gtk_widget_size_request(priv->d_event_box_image, &img_req);
+    gtk_widget_size_request(priv->d_button_image, &img_req);
 
     /* calculate our size */
     requisition->width = f_req.width + img_req.width + HILDON_MARGIN_DEFAULT;
@@ -1230,14 +1245,14 @@ static void hildon_date_editor_size_allocate(GtkWidget * widget,
         }
 
     /* allocate icon */
-        if (GTK_WIDGET_VISIBLE(priv->d_event_box_image)) {
-            gtk_widget_get_child_requisition(priv->d_event_box_image,
+        if (GTK_WIDGET_VISIBLE(priv->d_button_image)) {
+            gtk_widget_get_child_requisition(priv->d_button_image,
                                              &req);
 
             img_alloc.x += f_alloc.width + HILDON_MARGIN_DEFAULT;
             img_alloc.width = req.width;
             img_alloc.height = max_req.height;
-            gtk_widget_size_allocate(priv->d_event_box_image, &img_alloc);
+            gtk_widget_size_allocate(priv->d_button_image, &img_alloc);
         }
 
     /* FIXME: We really should not alloc delimeters by hand (since they
