@@ -1,14 +1,14 @@
 /*
  * This file is part of hildon-libs
  *
- * Copyright (C) 2005 Nokia Corporation.
+ * Copyright (C) 2005, 2006 Nokia Corporation, all rights reserved.
  *
- * Contact: Luc Pionchon <luc.pionchon@nokia.com>
+ * Contact: Michael Dominic Kostrzewa <michael.kostrzewa@nokia.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
- * as published by the Free Software Foundation; either version 2.1 of
- * the License, or (at your option) any later version.
+ * as published by the Free Software Foundation; version 2.1 of
+ * the License.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -373,6 +373,12 @@ hildon_find_toolbar_emit_search(GtkButton *button, gpointer self)
 static void
 hildon_find_toolbar_emit_close(GtkButton *button, gpointer self)
 {
+  HildonFindToolbarPrivate *priv = HILDON_FIND_TOOLBAR(self)->priv;
+  GtkWidget *entry = gtk_bin_get_child(GTK_BIN(priv->entry_combo_box));
+  if (GTK_WIDGET_HAS_FOCUS(entry))
+    {
+      hildon_gtk_im_context_hide(GTK_ENTRY(entry)->im_context);
+    }
   /* Clicked close button */
   g_signal_emit_by_name(self, "close", NULL);
 }
@@ -386,25 +392,18 @@ hildon_find_toolbar_emit_invalid_input(GtkEntry *entry,
     g_signal_emit_by_name(self, "invalid_input", NULL);
 }
 
-static gboolean
-hildon_find_toolbar_entry_key_press (GtkWidget *widget,
-                                    GdkEventKey *event,
+static void
+hildon_find_toolbar_entry_activate (GtkWidget *widget,
                                     gpointer user_data)
 {
   GtkWidget *find_toolbar = GTK_WIDGET(user_data);
-  
-  /* on enter we emit search and history_append signals and keep
-   * focus by returning true */
-  if (event->keyval == GDK_KP_Enter)
-    {
-      gboolean rb;  
-      g_signal_emit_by_name(find_toolbar, "search", NULL);
-      g_signal_emit_by_name(find_toolbar, "history_append", &rb, NULL);
+  gboolean rb;  
 
-      return TRUE;
-    }
+  /* NB#40936 stop focus from moving to next widget */
+  g_signal_stop_emission_by_name (widget, "activate");
 
-  return FALSE;      
+  g_signal_emit_by_name(find_toolbar, "search", NULL);
+  g_signal_emit_by_name(find_toolbar, "history_append", &rb, NULL);
 }
 
 static void
@@ -559,8 +558,8 @@ hildon_find_toolbar_init(HildonFindToolbar *self)
   gtk_widget_show_all(GTK_WIDGET(entry_combo_box_container));
   gtk_toolbar_insert (GTK_TOOLBAR(self), entry_combo_box_container, -1);
   g_signal_connect(hildon_find_toolbar_get_entry(self->priv),
-                    "key-press-event",
-                    G_CALLBACK(hildon_find_toolbar_entry_key_press), self);
+                    "activate",
+                    G_CALLBACK(hildon_find_toolbar_entry_activate), self);
 
   /* Find button */
   self->priv->find_button = gtk_tool_button_new (
