@@ -1,14 +1,14 @@
 /*
  * This file is part of hildon-libs
  *
- * Copyright (C) 2005 Nokia Corporation.
+ * Copyright (C) 2005, 2006 Nokia Corporation, all rights reserved.
  *
- * Contact: Luc Pionchon <luc.pionchon@nokia.com>
+ * Contact: Michael Dominic Kostrzewa <michael.kostrzewa@nokia.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
- * as published by the Free Software Foundation; either version 2.1 of
- * the License, or (at your option) any later version.
+ * as published by the Free Software Foundation; version 2.1 of
+ * the License.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -96,7 +96,8 @@ enum
   PROP_STRIKETHROUGH_SET,
   PROP_POSITION,
   PROP_POSITION_SET,
-  PROP_PREVIEW_TEXT
+  PROP_PREVIEW_TEXT,
+  PROP_FONT_SCALING
 };
 
 typedef struct
@@ -131,6 +132,11 @@ struct _HildonFontSelectionDialogPrivate
    * when we change the color setting*/
   
   gboolean color_set;
+
+  /* font_scaling is the scaling factor applied to font
+   * scale in the preview dialog */
+
+  gdouble font_scaling;
   gulong color_modified_signal_handler;
 };
 
@@ -385,7 +391,11 @@ hildon_font_selection_dialog_get_property (GObject      *object,
       else
 	g_value_set_int(value, 0);
       break;
-      
+    
+    case PROP_FONT_SCALING:
+	g_value_set_double(value, priv->font_scaling);
+      break;
+  
     case PROP_POSITION_SET:
       i = gtk_combo_box_get_active(GTK_COMBO_BOX(priv->cbx_positioning));
       if(i >= 0 && i < 3)
@@ -552,6 +562,10 @@ hildon_font_selection_dialog_set_property (GObject         *object,
       else
 	gtk_combo_box_set_active(GTK_COMBO_BOX(priv->cbx_positioning), 0);
       break;
+
+    case PROP_FONT_SCALING:
+      priv->font_scaling = g_value_get_double(value);
+      break;
       
     case PROP_POSITION_SET:
       b = g_value_get_boolean(value);
@@ -687,6 +701,16 @@ hildon_font_selection_dialog_class_init(HildonFontSelectionDialogClass *
 				   "Font position super or subscript",
 				   -1, 1, 0,
 				   G_PARAM_READWRITE));
+
+  /* FIXME This was introduced in 0.14.1. We don't have documentation for 
+   * properties anyways, but once it's there it needs to be marked as 
+   * Since: 0.14.1 */
+  g_object_class_install_property(gobject_class, PROP_FONT_SCALING,
+				   g_param_spec_double ("font-scaling",
+				   "Font scaling",
+				   "Font scaling for the preview dialog",
+				   0, 10, 1,
+				   G_PARAM_READWRITE));
   
   g_object_class_install_property(gobject_class, PROP_POSITION_SET,
 				  g_param_spec_boolean ("position-set",
@@ -793,6 +817,7 @@ hildon_font_selection_dialog_construct_notebook (HildonFontSelectionDialog
   font_color_box = gtk_hbox_new(FALSE, 0);
   priv->font_color_button = hildon_color_button_new();
   priv->color_set = FALSE;
+  priv->font_scaling = 1.0;
   priv->color_modified_signal_handler = 
     g_signal_connect(G_OBJECT(priv->font_color_button), "notify::color",
 		     G_CALLBACK(color_modified_cb), (gpointer) priv);
@@ -953,6 +978,7 @@ hildon_font_selection_dialog_create_attrlist(HildonFontSelectionDialog *
 	   strikethrough, strikethrough_set, position_set;
   GdkColor *color = NULL;
   gchar *family = NULL;
+  gdouble font_scaling = 1.0;
 
   list = pango_attr_list_new();
  
@@ -965,7 +991,9 @@ hildon_font_selection_dialog_create_attrlist(HildonFontSelectionDialog *
 	       "underline", &underline, "underline-set", &underline_set,
 	       "strikethrough", &strikethrough, "strikethrough-set", 
 	       &strikethrough_set, "position", &position, 
-	       "position-set", &position_set, NULL);
+	       "position-set", &position_set, 
+               "font-scaling", &font_scaling,
+               NULL);
 
   /*family*/
   if(family_set)
@@ -1054,7 +1082,14 @@ hildon_font_selection_dialog_create_attrlist(HildonFontSelectionDialog *
 
       add_preview_text_attr(list, attr, start_index, len);
     }
-  
+
+  /*font scaling for preview*/
+  if(font_scaling)
+    {
+      attr = pango_attr_scale_new(font_scaling);
+      add_preview_text_attr(list, attr, 0, len + start_index);
+    }
+   
   return list;
 }
 
@@ -1071,6 +1106,16 @@ hildon_font_selection_dialog_show_preview(HildonFontSelectionDialog *
   GtkWidget *preview_dialog;
   GtkWidget *preview_label;
   gchar *str = NULL;
+  gboolean position_set = FALSE;
+  gint position = 0;
+  gboolean show_ref = FALSE;
+
+  g_object_get(G_OBJECT(fontsel), "position-set", &position_set, NULL);
+  if (position_set) {
+    g_object_get(G_OBJECT(fontsel), "position", &position, NULL);
+    if (position == 1 || position == -1)
+      show_ref = TRUE;
+  }
   
   /*Preview dialog init*/
   preview_dialog=
@@ -1082,12 +1127,12 @@ hildon_font_selection_dialog_show_preview(HildonFontSelectionDialog *
 				GTK_RESPONSE_ACCEPT,
 				NULL);
 
-  str = g_strconcat(_("ecdg_fi_preview_font_preview_reference"),
-                    priv->preview_text, 0);
+  str = (show_ref) ? g_strconcat(_("ecdg_fi_preview_font_preview_reference"), priv->preview_text, 0) :
+                     g_strdup (priv->preview_text);
 
   preview_label = gtk_label_new(str);
   gtk_label_set_line_wrap(GTK_LABEL(preview_label), TRUE);
-
+  
   g_free(str);
   str = NULL;
 
@@ -1102,13 +1147,25 @@ hildon_font_selection_dialog_show_preview(HildonFontSelectionDialog *
   
   
   /*Set the font*/
-  list = hildon_font_selection_dialog_create_attrlist(fontsel, 
-				strlen(_("ecdg_fi_preview_font_preview_reference")),
-				strlen(priv->preview_text));
+  list = (show_ref) ? hildon_font_selection_dialog_create_attrlist(fontsel, 
+      strlen(_("ecdg_fi_preview_font_preview_reference")),
+      strlen(priv->preview_text)) :
+      hildon_font_selection_dialog_create_attrlist(fontsel, 
+      0,
+      strlen(priv->preview_text));
 
   g_object_get(G_OBJECT(fontsel), "family", &str, "family-set",
 	       &family_set, "size", &size, "size-set", &size_set,
 	       NULL);
+
+  /* FIXME: This is a slightly ugly hack to force the width of the window so that
+   * the whole text fits with various font sizes. It's being done in such a way, 
+   * because of some GtkLabel wrapping issues and other mysterious bugs related to 
+   * truncating ellipsizing. Needs a rethink in future. (MDK) */
+
+  gint dialog_width = (size_set && size > 24) ? 600 : 500; 
+  gtk_window_set_default_size (GTK_WINDOW(preview_dialog), dialog_width, -1);
+
   /*make reference text to have the same fontface and size*/
   if(family_set)
     {
@@ -1130,6 +1187,7 @@ hildon_font_selection_dialog_show_preview(HildonFontSelectionDialog *
   /*And show the dialog*/
   gtk_window_set_transient_for(GTK_WINDOW(preview_dialog), 
 			       GTK_WINDOW(fontsel));
+
   gtk_widget_show_all(preview_dialog);
   gtk_dialog_run(GTK_DIALOG(preview_dialog));
   gtk_widget_destroy(preview_dialog);
@@ -1139,6 +1197,9 @@ hildon_font_selection_dialog_show_preview(HildonFontSelectionDialog *
 static gboolean is_internal_font(const gchar * name){
   return strcmp(name, "DeviceSymbols") == 0
       || strcmp(name, "Nokia Smiley" ) == 0
+      || strcmp(name, "NewCourier" ) == 0
+      || strcmp(name, "NewTimes" ) == 0
+      || strcmp(name, "SwissA" ) == 0
       || strcmp(name, "Nokia Sans"   ) == 0
       || strcmp(name, "Nokia Sans Cn") == 0;
 }
@@ -1220,7 +1281,7 @@ hildon_font_selection_dialog_show_available_sizes
 
   for (i = 0; i < G_N_ELEMENTS(font_sizes); i++) 
     {
-      size_str = g_strdup_printf ("%i %s",
+      size_str = g_strdup_printf ("%i%s",
 				  font_sizes[i],
 				  _("ecdg_va_font_size_trailer"));
 
