@@ -1,14 +1,14 @@
 /*
  * This file is part of hildon-libs
  *
- * Copyright (C) 2006 Nokia Corporation.
+ * Copyright (C) 2006 Nokia Corporation, all rights reserved.
  *
- * Contact: Luc Pionchon <luc.pionchon@nokia.com>
+ * Contact: Michael Dominic Kostrzewa <michael.kostrzewa@nokia.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
- * as published by the Free Software Foundation; either version 2.1 of
- * the License, or (at your option) any later version.
+ * as published by the Free Software Foundation; version 2.1 of
+ * the License.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -23,8 +23,8 @@
  */
 
 
-#ifndef HILDON_PRIVATE_H
-#define HILDON_PRIVATE_H
+#ifndef __HILDON_PRIVATE_H__
+#define __HILDON_PRIVATE_H__
 
 #include <gtk/gtklabel.h>
 
@@ -35,4 +35,4 @@ _hildon_time_editor_get_time_separators(GtkLabel *hm_sep_label,
                                         GtkLabel *ms_sep_label);
 
 G_END_DECLS
-#endif /* HILDON_PRIVATE_H */
+#endif /* __HILDON_PRIVATE_H__ */
