@@ -1,14 +1,14 @@
 /*
  * This file is part of hildon-libs
  *
- * Copyright (C) 2005 Nokia Corporation.
+ * Copyright (C) 2005, 2006 Nokia Corporation, all rights reserved.
  *
- * Contact: Luc Pionchon <luc.pionchon@nokia.com>
+ * Contact: Michael Dominic Kostrzewa <michael.kostrzewa@nokia.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
- * as published by the Free Software Foundation; either version 2.1 of
- * the License, or (at your option) any later version.
+ * as published by the Free Software Foundation; version 2.1 of
+ * the License.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -243,6 +243,8 @@ create_contents(HildonSetPasswordDialog *dialog)
 
     /* Create the password field */
     priv->pwd1stEntry = gtk_entry_new();
+    g_object_set (priv->pwd1stEntry, "hildon-input-mode", HILDON_GTK_INPUT_MODE_FULL, NULL);
+    gtk_entry_set_visibility(GTK_ENTRY(priv->pwd1stEntry), FALSE);
     gtk_widget_show(priv->pwd1stEntry);
     priv->pwd1stCaption = hildon_caption_new(group,
                                         priv->pwd1stCaption_string,
@@ -256,6 +258,7 @@ create_contents(HildonSetPasswordDialog *dialog)
 
     /* Create the password verify field */
     priv->pwd2ndEntry = gtk_entry_new();
+    g_object_set (priv->pwd2ndEntry, "hildon-input-mode", HILDON_GTK_INPUT_MODE_FULL, NULL);
     gtk_widget_show(priv->pwd2ndEntry);
     priv->pwd2ndCaption = hildon_caption_new(group,
                                         priv->pwd2ndCaption_string,
