@@ -63,6 +63,7 @@
 #include "hildon-libs-enum-types.h"
 
 #define _(String) dgettext(PACKAGE, String)
+#define c_(String) dgettext("hildon-common-strings", String)
 
 #define HILDON_TIME_EDITOR_GET_PRIVATE(obj) \
     (G_TYPE_INSTANCE_GET_PRIVATE ((obj), \
@@ -1731,7 +1732,7 @@ static gboolean hildon_time_editor_entry_keypress(GtkWidget * widget,
        (only digits and control characters are allowed )*/
     if (!g_unichar_isdigit(event->keyval) && !(event->keyval & 0xF000)) {
         g_signal_emit(editor, time_editor_signals[TIME_ERROR], 0, INVALID_CHAR, &r);
-        hildon_banner_show_information(widget, NULL, _("ckct_ib_illegal_character"));
+        hildon_banner_show_information(widget, NULL, c_("ckct_ib_illegal_character"));
         return TRUE;
     }
 
